<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field</source>
        <translation>Polje</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field name</source>
        <translation>Ime polja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Field description</source>
        <translation>Opis polja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Value</source>
        <translation>Vrijednost</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Field value</source>
        <translation>Vrijednost polja</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>Izađi pri zatvaranju</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>Zapamti mjesto</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>Traženje imena računala</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>Traženje imena usluge</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation>Trokuti rasklapanja</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation>Crte grana</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Automatski spremi postavke pri zatvaranju programa</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Odabir: Kopiraj ID oznake procesa u međuspremnik</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>Normaliziraj NICE</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>Koristi pmap za imena mapiranja</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation>Opće</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="634"/>
        <source>Linear</source>
        <translation>Linearno</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="637"/>
        <source>Tree</source>
        <translation>Stablo</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="646"/>
        <source>Thread</source>
        <translation>Niz</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="653"/>
        <source>All Processes</source>
        <translation>Svi procesi</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="654"/>
        <source>Your Processes</source>
        <translation>Tvoji procesi</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="655"/>
        <source>Non-Root Processes</source>
        <translation>Ne-administratorski procesi</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="656"/>
        <source>Running Processes</source>
        <translation>Procesi u tijeku</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="672"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pauza (Ctrl+razmaknica)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Proces %1 ( %2 ) – detalji</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>Datoteke</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>Utičnice</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Mape memorije</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Okruženje</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Sva polja</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable</source>
        <translation>Varijabla</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable name</source>
        <translation>Ime varijable</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Value</source>
        <translation>Vrijednost</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Variable value</source>
        <translation>Vrijednost varijable</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Odaberi prilagođena polja </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>Fd</source>
        <translation>Deskriptor datoteka</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>File descriptor</source>
        <translation>Deskriptor datoteka</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Open mode</source>
        <translation>Otvori modus</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>File name (if available)</source>
        <translation>Ime datoteke (ako postoji)</translation>
    </message>
</context>
<context>
    <name>IO_Graph</name>
    <message>
        <location filename="../infobar.cpp" line="785"/>
        <source>I/O Summary:</source>
        <translation>Sažetak unosa/rezultata:</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="819"/>
        <source>No input or output</source>
        <translation>Nema unosa niti rezultata</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>Promijeni vrijeme aktualiziranja</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>Novo vrijeme aktualiziranja</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation>Bez AKTUALIZIRANJA</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>Neispravna vrijednost</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>Raspon adresa</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Mapirane adrese (hex) )</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>Veličina</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>Kilobajta mapiprano (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation>Dozvola</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>Oznake dozvole</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>Odmak</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Odmak datoteke na početku mapiranja (hex)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>Uređaj</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>Glavni,Sporedni brojevi uređaja (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation>Inode</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation>Inode broj (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>Ime datoteke (ako postoji)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>Dozvola</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>Root lozinka</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation>Postava</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation>Postotak procesora podijeljen s</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>Ukupno procesora: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation>Jedan procesor: 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation>standardno</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>za programere</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>Process ID</source>
        <translation>ID procesa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>TGID</source>
        <translation>TGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>ID grupe zadataka( nedređeni )</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>PPID</source>
        <translation>PPID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>Parent process ID</source>
        <translation>ID nadređenog procesa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>PGID</source>
        <translation>PGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>Process group ID</source>
        <translation>ID grupe procesa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>SID</source>
        <translation>SID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>Session ID</source>
        <translation>ID sesije</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>TTY</source>
        <translation>TTY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>TPGID</source>
        <translation>TPGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>Process group ID of tty owner</source>
        <translation>ID grupe procesa ili vlasnik terminala</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>USER</source>
        <translation>USER</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Vlasnik (*=suid aministratora, +=suid korisnika)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>GROUP</source>
        <translation>GROUP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>Group name (*=sgid other)</source>
        <translation>Ime grupe (*=sgid ostalih)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>Real user ID</source>
        <translation>ID stvarnog korisnika</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>EUID</source>
        <translation>EUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>Effective user ID</source>
        <translation>ID efektivnog korisnika</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>SUID</source>
        <translation>SUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>Saved user ID (Posix)</source>
        <translation>Spremljen ID korisnika (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>FSUID</source>
        <translation>FSUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>File system user ID</source>
        <translation>ID korisnika datotečnog sustava</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>GID</source>
        <translation>GID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>Real group ID</source>
        <translation>ID stvarne grupe</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>EGID</source>
        <translation>EGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>Effective group ID</source>
        <translation>ID efektivne grupe</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>SGID</source>
        <translation>SGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>Saved group ID (Posix)</source>
        <translation>Spremljen ID grupe (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>FSGID</source>
        <translation>FSGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>File system group ID</source>
        <translation>ID grupe datotečnog sustava</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>PRI</source>
        <translation>PRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>Dynamic priority</source>
        <translation>Dinamičan prioritet</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>NICE</source>
        <translation>NICE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>Prioriziranje planiranja (veće -&gt; manje vrijeme procesora)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>NLWP</source>
        <translation>NLWP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Broj zadataka (niti) u grupi zadataka</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>PLCY</source>
        <translation>PLCY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>Scheduling policy</source>
        <translation>Politika planiranja</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>RPRI</source>
        <translation>RPRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Prioritet u stvarnom vremenu (0 do 99, više je bolje)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>TMS</source>
        <translation>TMS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>Time slice in milliseconds</source>
        <translation>Isječci vremena u milisekundama</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>%SAVG</source>
        <translation>%SAVG</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Postotak prosječnog mirovanja (−1 -&gt; --)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>CPUSET</source>
        <translation>CPUSET</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>Maska dodjele procesora (0 -&gt; sučelje nije podržano)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>MAJFLT</source>
        <translation>MAJFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>Number of major faults (disk access)</source>
        <translation>Broj važnih pogrešaka (pristup disku)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>MINFLT</source>
        <translation>MINFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Broj manje važnih pogrešaka (bez pristupa disku)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>VSIZE</source>
        <translation>VSIZE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>Virtual image size of process</source>
        <translation>Virtualna veličina slike procesa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>RSS</source>
        <translation>RSS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>Resident set size</source>
        <translation>Veličina rezidentne memorije</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>MEM</source>
        <translation>MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>upotreba memorije (RSS-SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>TRS</source>
        <translation>TRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>Text(code) resident set size</source>
        <translation>Veličina rezidentne memorije za tekst (kod)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>DRS</source>
        <translation>DRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation>Veličina rezidentne memorije za podatke (malloc+globalna varijabla)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>STACK</source>
        <translation>STACK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>Stack size</source>
        <translation>Stack veličina</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>SHARE</source>
        <translation>SHARE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>Shared memory with other libs</source>
        <translation>Dijeljena memorija s drugim bibliotekama</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>SWAP</source>
        <translation>SWAP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>Kbytes on swap device</source>
        <translation>Kilobajta na virtualnom uređaju</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>IO_R</source>
        <translation>IO_R</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>io read (file)</source>
        <translation>unos/rezultat čitanje (datoteka)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>IO_W</source>
        <translation>IO_W</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>io write (file)</source>
        <translation>unos/rezultat pisanje (datoteka)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>DT</source>
        <translation>DT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Broj zmazanih (ne zapisanih) stranica</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>STAT</source>
        <translation>STAT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>State of the process </source>
        <translation>Stanje procesa </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>FLAGS</source>
        <translation>FLAGS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>Process flags (hex)</source>
        <translation>Oznake procesa (hex)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>WCHAN</source>
        <translation>WCHAN</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Funkcija kernela, gdje proces spava</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>%WCPU</source>
        <translation>%WCPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>Ponderiran postatak procesora (30 s prosječno)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>%CPU</source>
        <translation>%CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Postotak procesora koji je korišten od zadnjeg aktualiziranja</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>%MEM</source>
        <translation>%MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Postotak korištene memorije (RSS/ukupna memorija)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>Time process started</source>
        <translation>Vrijeme pokretanja procesa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>TIME</source>
        <translation>TIME</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>Total CPU time used since start</source>
        <translation>Ukupno vrijeme procesora od pokretanja sve do sada</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>Procesor na kojem se izvršava proces (SMP sustav)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>the process name</source>
        <translation>ime procesa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>Process Name</source>
        <translation>Ime procesa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>CWD</source>
        <translation>CWD</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>Current working directory</source>
        <translation>Trenutačna radna mapa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>ROOT</source>
        <translation>ROOT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>Root directory of process</source>
        <translation>Administrativna mapa procesa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>COMMAND_LINE</source>
        <translation>COMMAND_LINE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>Command line that started the process</source>
        <translation>Naredbeni redak koji je pokrenuo proces</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1628"/>
        <source>Show</source>
        <translation>Prikaži</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1631"/>
        <source>Hide</source>
        <translation>Sakrij</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1636"/>
        <source>Quit</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="437"/>
        <source>User: </source>
        <translation>Korisnik: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="438"/>
        <source>System: </source>
        <translation>Sustav: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>Nice: </source>
        <translation>Nice: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="437"/>
        <location filename="../infobar.cpp" line="438"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="474"/>
        <location filename="../infobar.cpp" line="509"/>
        <source>Total: </source>
        <translation>Ukupno: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="477"/>
        <location filename="../infobar.cpp" line="515"/>
        <source>Used: </source>
        <translation>Korišteno: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="481"/>
        <source>Cached: </source>
        <translation>U predmemoriji: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="484"/>
        <source>Buffer: </source>
        <translation>Međumemorija: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="512"/>
        <source>Free: </source>
        <translation>Dostupno: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="554"/>
        <source>Time passed after system boot</source>
        <translation>Proteklo vrijeme nakon pokretanja sustava</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="582"/>
        <source>Average CPU load each 1, 5 ,15 minutes</source>
        <translation>Prosječno opterećenje CPU-a svakih 1, 5 , 15 minuta</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="727"/>
        <source>CPU Usage Summary:</source>
        <translation>Sažetak korištenja CPU-a:</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="171"/>
        <source>header_popup</source>
        <translation>skočno_zaglavlje</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="172"/>
        <source>Remove Field</source>
        <translation>Ukloni polje</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="173"/>
        <source>Add Field</source>
        <translation>Dodaj polje</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="176"/>
        <source>Session</source>
        <translation>Sesija</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="180"/>
        <source>View</source>
        <translation>Prikaz</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="181"/>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="182"/>
        <source>Log</source>
        <translation>Log-zapis</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="187"/>
        <source>Fields</source>
        <translation>Polja</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="188"/>
        <source>Custom Fields</source>
        <translation>Prilagođena polja</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Basic Fields </source>
        <translation>Osnovna polja </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="192"/>
        <source>Jobs Fields </source>
        <translation>Polja poslova </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="194"/>
        <source>Memory Fields </source>
        <translation>Polja memorije </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Scheduling Fields </source>
        <translation>Polja planiranja </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="214"/>
        <source>Select Custom Fields...</source>
        <translation>Odaberi prilagođena polja …</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="223"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="224"/>
        <source>Update Period...</source>
        <translation>Vrijeme aktualiziranja …</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="233"/>
        <source>Show Status bar</source>
        <translation>Prikaži traku stanja</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="242"/>
        <source>Preferences...</source>
        <translation>Postavke …</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="248"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="249"/>
        <location filename="../qps.cpp" line="1676"/>
        <source>About</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="330"/>
        <source>test</source>
        <translation>test</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="331"/>
        <source>Copied to Clipboard</source>
        <translation>Kopirano u međuspremnik</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="383"/>
        <source>context popup</source>
        <translation>kontekstualni skočni izbornik</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="384"/>
        <source>Renice...</source>
        <translation>Ponovo upotrijebi nice …</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="385"/>
        <source>Scheduling...</source>
        <translation>Planiranje …</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="387"/>
        <source>Terminate</source>
        <translation>Ukini</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="388"/>
        <source>Hangup</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="389"/>
        <source>Kill</source>
        <translation>Ubij</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="390"/>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="392"/>
        <source>Continue</source>
        <translation>Nastavi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>Other Signals</source>
        <translation>Drugi signali</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="396"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (privremeno prekini)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="398"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (nastavi)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="400"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (zaustavi)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="402"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (zatvori)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="404"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (nedozvoljena instrukcija)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="406"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (prekini)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="408"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (iznimka s pomičnim zarezom)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="410"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (povreda segmentacije)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="412"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (pokvareni pipe)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="414"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (signal tajmera)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="416"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (korisnički definirano 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="418"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (korisnički definirano 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="420"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (smrt podređenog)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="422"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (zaustavi iz terminala)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="424"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (unos terminala)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="426"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (rezultat terminala)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="433"/>
        <source>View Details</source>
        <translation>Prikaži detalje</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="671"/>
        <source>Show File Path</source>
        <translation>Pokaži stazu datoteke</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="677"/>
        <source>Show Graph</source>
        <translation>Pokaži grafikon</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="683"/>
        <source>Show Control Bar</source>
        <translation>Prikaži traku kontrola</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="694"/>
        <source>Include Child Times</source>
        <translation>Uključi vremena podređenog</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="282"/>
        <source>Quit</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1139"/>
        <location filename="../qps.cpp" line="1170"/>
        <location filename="../qps.cpp" line="1177"/>
        <location filename="../qps.cpp" line="1198"/>
        <location filename="../qps.cpp" line="1232"/>
        <location filename="../qps.cpp" line="1327"/>
        <source>Permission denied</source>
        <translation>Nedozvoljeno</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1140"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>Nemaš dozvolu za upotrebu naredbe renice za odabrane procese. To smiju samo vlasnik procesa i super korisnik.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1171"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>Nemaš dozvolu za upotrebu naredbe renice za proces %1 (%2). To smiju samo vlasnik procesa i super korisnik.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1178"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>Samo super korisnik smije smanjiti nice-vrijednost procesa..</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1199"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>Samo super korisnik smije promijeniti politiku planiranja i prioritet.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1233"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>Nemaš dozvolu za mijenjanje planiranja i/ili prioriteta procesa %1 (%2). To smije samo super korisnik.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1294"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation>Stvarno želiš prekinuti odabrane procese?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1296"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation>Stvarno želiš završiti odabrane procese?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1298"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation>Stvarno želiš okončati odabrane procese?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1307"/>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1328"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>Nemaš dozvolu za slanje signala procesu %1 (%2). To smiju samo super korisnik i vlasnik procesa.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1692"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1694"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation>&lt;h2&gt; Qps %1 – Vizualan upravljač procesa &lt;/h2&gt; %2 koristeći Qt biblioteku %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Izvor: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Sustav za praćenje grešaka: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1714"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;Izvorni Qps od&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Doprinositelji&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>Promijeni planiranje</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>Politika planiranja</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>SCHED_OTHER (dijeljenje vremena)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (stvarno vrijeme)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (stvarno vrijeme)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation>Prioritet (1 do 99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation>Neispravan unos</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>Prioritet mora biti u rasponu od 1 do 99</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="588"/>
        <source>PID, COMMAND, USER...</source>
        <translation>PID, COMMAND, USER...</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="589"/>
        <source>Filter</source>
        <translation>Filtar</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation>Proces ponovne upotrebe naredbe nice</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation>Nova vrijednost za nice:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation>Deskriptor datoteka</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation>Deskriptor datoteka</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Protokol (TCP ili UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation>Red primanja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>Bajtova u redu čekanja primanja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation>Red slanja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>Bajtova u redu čekanja slanja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation>Lokalna adresa</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>Lokalna IP adresa</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation>Priključak</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>Lokalni priključak</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation>Udaljena adresa</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>Udaljena IP adresa</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>Udaljeni priključak</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>Stanje</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>Stanje veze</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="624"/>
        <source>Process count: %1</source>
        <translation>Broj procesa: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="343"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> Ovo je nestabilna Alpha funkcija
 Možda ćeš doživjeti SEGFAULT …</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="485"/>
        <source>title</source>
        <translation>naslov</translation>
    </message>
</context>
</TS>
